
Developer Manual
================

.. toctree::

   contributing.rst
   architecture.rst
   extending-frontend.rst
   extending-backend.rst
   dispatching.rst
   generators.rst
   numba-runtime.rst
   rewrites.rst
